#ifndef BOB_H_
#define BOB_H_

int bobMcBob(void);

#endif
